(_components)=
# Setting up the Calculation


[Setting up the Model Geometry](components/model_geometry.md)
: Configuration of global model grids (e.g. altitude), the global type of geometry (spherical, plane-parallel)

[Specifying what you Want to Calculate](components/viewing_geometry.md)
: Setting up viewing directions for radiance output.

[Choosing and Configuring Atmospheric Sources](components/sources.md)
: Determining what source terms to include (e.g. multiple scatter, thermal sources)

[Setting the Atmospheric State](components/atmosphere.md)
: Setting up atmospheric constituents like Rayleigh scattering and ozone absorption



```{toctree}
:maxdepth: 2
:hidden:

components/model_geometry
components/viewing_geometry
components/sources
components/atmosphere
```
